function [output] = showSaliencyMap(imgName,thresh,dispMap)
%% PURPOSE: Generate & Show the SALIENCY map for an image
% ==>  Input Arguments:
%      imgName (example- 'U0121_1RTE.jpg') ... default: 'testImg.jpg'
%      thresh  (example- [0.1 0.2 0.3]) ... default: [0.05 0.25] which is 5% & 25% of img
%      dispMap  (0 [No] or 1 [Yes]) ... default: 1
% ==>  Output: output.salMap

%% SET UP:
%Folders:
warning off
HOME = pwd;
init(HOME)

%Load Image:
if ~exist('imgName','var');
    load stimList
    stimList = stimList_ALL(randperm(length(stimList_ALL)))';
    imgName = [stimList{1} '.jpg'];
end
imgPath = which(imgName);
if isempty(imgPath);
    disp(['ERROR:  ' imgName '  was not found ']); return;
else
    img = imread([imgName]);
end;

%Set Thresholds:
if ~exist('thresh','var'); thresh = [0.05 0.25]; end

%Initialize stuff:
stimSize = size(img);  stimSize = stimSize(1:2);  %stimulus dimensions
Tsal_px = thresh * (stimSize(1)*stimSize(2));
exponentSAL = 0.025;                % modulates: SALIENCY MAP
exponentINRIA = 0.025;              % modulates: OBJECT MAP (INRIA)
whiteMat = zeros(stimSize);         %blank matrix

%Figure stuff:
scnsize = get(0,'ScreenSize');
fullscn=[5 40  scnsize(3)-10 scnsize(4)-120];

%Display stuff
if ~exist('dispMap','var'); dispMap = 1; end

%% ========================================================= %%
%% Load data (mean context oracle map)
imgPath = which([imgName(1:end-4) '_SaliencyMap.mat']);
if isempty(imgPath); %Calculate saliency map for this image:

    %% Resizing the image speeds things up:
    if stimSize(1) >= 600; salMapDownsize = 2; else;  salMapDownsize = 1; end
    img_resized = imresize(img,1/salMapDownsize);
    [mIMA,nIMA,p]=size(img_resized);
    disp(['Image: ' imgName ]); disp(['Running Saliency Code on image: ' imgName ' ...'])

    %% Set parameters for salient features:
    Nsc = 4; % # of scales
    Nor = 4; % # of orientations
    Rinhibition = 40; % Radium of inhibition (used when identifying top N most salient points)

    [vL, vLind]=features(img, Nsc, Nor);
    l=0;
    X = zeros(mIMA*nIMA,p*Nsc*Nor);
    for n=1:size(img,3)
        for b=2:size(vLind,1)-1
            x =  (pyrBand(vL(:,n),vLind(:,:,n),b));
            x = imresize(x, [mIMA,nIMA], 'nearest');
            x = (x - mean(x(:)))/std(x(:));
            l=l+1;
            X(:,l)=x(:);
        end
    end

    [mu, cY, k] = fitPowerExponential (X,2);
    saliencyMap = powerExponential(X, mu, cY, k);
    saliencyMap = 1./saliencyMap;
    saliencyMap = reshape(saliencyMap, [mIMA nIMA]);

    salMap_Blur = real(gaussian(saliencyMap.^exponentSAL, 8));
    salMap_Blur = imresize(salMap_Blur,salMapDownsize); salMap = salMap_Blur;

    %% Save output:
    output.salMap = salMap_Blur;
    % for t = 1:length(Tsal_px)
    %     [imgFixRegions_thresh{t}] = findPredRegion(salMap_Blur,Tsal_px(t),0);
    %     eval(['output.salMap_' num2str(thresh(t)*100) 'per_Thresh = imgFixRegions_thresh{t} ;'])
    % end
    save(fullfile(HOME,'saliencyMaps',[imgName(1:end-4) '_SaliencyMap.mat']),'salMap')
else
    x = load(imgPath);
    output.salMap = x.salMap;
end;

%% ========================================================= %%
%% DISPLAY:
if dispMap
    map = output.salMap;
    figure('Position',fullscn,'Name',['SALIENCY MAP for: ' imgName]);
    subplot(2,2,1:2);
    imagesc(img); title([ 'Original Stimulus: ' imgName]); axis off equal; hold on;
    for t = 1:2
        [imgFixRegions_thresh{t}] = findPredRegion(salMap_Blur,Tsal_px(t),0);
        subplot(2,2,t+2)
        title(['SALIENCY Defined Region: Thresh ' num2str(thresh(t)*100) '%']); colormap(gray); axis off equal; hold on;
        imagesc(imgFixRegions_thresh{t}.*double(img(:,:,1)));
    end
end
